# locloc

[![PyPI version](https://badge.fury.io/py/locloc.svg)](https://badge.fury.io/py/locloc) [![Maintainability](https://api.codeclimate.com/v1/badges/2a065d7fbf4b174b0f94/maintainability)](https://codeclimate.com/github/eggplants/locloc/maintainability) [![pre-commit.ci status](https://results.pre-commit.ci/badge/github/eggplants/locloc/master.svg)](https://results.pre-commit.ci/latest/github/eggplants/locloc/master) [![Test Coverage](https://api.codeclimate.com/v1/badges/2a065d7fbf4b174b0f94/test_coverage)](https://codeclimate.com/github/eggplants/locloc/test_coverage) [![Test](https://github.com/eggplants/locloc/actions/workflows/test.yml/badge.svg)](https://github.com/eggplants/locloc/actions/workflows/test.yml)

[![ghcr latest](https://ghcr-badge.deta.dev/eggplants/locloc/latest_tag?trim=major&label=latest) ![ghcr size](https://ghcr-badge.deta.dev/eggplants/locloc/size)](https://github.com/eggplants/locloc/pkgs/container/locloc)

Online LOC counter

## Related work

- <s><https://locfetch.app/></s> (closed)

  - ref: <https://zenn.dev/kyoheiu/articles/3f01fef8afe2c9>

- <https://codetabs.com/count-loc/count-loc-online.html>
  - source: <https://github.com/jolav/codetabs>
